@@ -1,13 +1,14 @@
 # from enum import Enum
 from time import strftime
 from os import mkdir, path, getcwd, environ
+import random
+import traceback
 from PIL import Image
 from typing import List
 from dataclasses import dataclass
 from huggingface_hub import login
 from diffusers import StableDiffusionPipeline, DPMSolverMultistepScheduler
-from profanity_check import predict as profanity_predict
-import traceback
+from profanity_check import predict_prob as profanity_predict_prob
 from multiskin.clean.clean_skin import clean_skin
 
 # class CreationType(Enum):
@@ -98,11 +99,16 @@ class Model:
         generated_filenames = []
         try:
             print(f"Inference config: {infer_config}")
-            if any(profanity_predict(prompts)):
+            profanity_likelihood = profanity_predict_prob(prompts)[0] # 0 to 1
+            print(f"Profanity likelihood: {profanity_likelihood}")
+            if  profanity_likelihood > 0.75:
                 raise ProfanityError
             for idx, prompt in enumerate(prompts):
                 print(f"Generating prompt [{idx}/{len(prompts)}]: [{prompt}]...")
-                tokened_prompt = f"{prompt} mc" if infer_config.creation_type is "SKIN" else f"{prompt}, sjh style"
+                cape_modifier = " pixelart," if random.random() > 0.5 else "" # randomly add "pixelart" to the prompt
+                cape_prompt = f"{prompt},{cape_modifier} sjh style"
+                skin_prompt = f"{prompt} mc"
+                tokened_prompt =  skin_prompt if infer_config.creation_type is "SKIN" else cape_prompt
                 images: List[Image.Image] = self.pipe(tokened_prompt, **self.pipeline_args(infer_config=infer_config)).images
                 filename = self.create_filename(prompt=prompt)
                 print(f"Generated images: {images}")
