@@ -8,7 +8,7 @@ class TestInference(unittest.TestCase):
     def test_inference(self, _mock):
         model_inst = Model()
         nif=1
-        prompt="spiderman mc"
+        prompt="spiderman"
         inf_conf = InferConfig(prompts=[prompt], num_inference_steps=nif, width=512, height=512)
         gen_filenames = model_inst.infer(infer_config=inf_conf)
         self.assertTrue('spiderman' in gen_filenames[0])
